@@ -1,7 +1,13 @@
 import datetime
 from mock import mock
+from unittest import skipIf
 
-import pandas as pd
+import numpy as np
+try:
+    import pandas as pd
+    is_pandas = True
+except ImportError as e:
+    is_pandas = False
 import pytest
 
 from bokeh.models import ColumnDataSource, CDSView, Marker
@@ -81,7 +87,7 @@ def test__stack_broadcast_with_no_kwargs():
     kws = _stack(stackers, 'start', 'end')
     assert len(kws) == len(stackers)
     for i, kw in enumerate(kws):
-        assert set(['start', 'end']) == set(kw.keys())
+        assert set(['start', 'end', 'name']) == set(kw.keys())
         assert list(kw['start']['expr'].fields) == stackers[:i]
         assert list(kw['end']['expr'].fields) == stackers[:(i+1)]
 
@@ -90,23 +96,51 @@ def test__stack_broadcast_with_scalar_kwargs():
     kws = _stack(stackers, 'start', 'end', foo=10, bar="baz")
     assert len(kws) == len(stackers)
     for i, kw in enumerate(kws):
-        assert set(['start', 'end', 'foo', 'bar']) == set(kw.keys())
+        assert set(['start', 'end', 'foo', 'bar', 'name']) == set(kw.keys())
         assert list(kw['start']['expr'].fields) == stackers[:i]
         assert list(kw['end']['expr'].fields) == stackers[:(i+1)]
         assert kw['foo'] == 10
         assert kw['bar'] == "baz"
+        assert kw['name'] == stackers[i]
 
 def test__stack_broadcast_with_list_kwargs():
     stackers = ['a', 'b', 'c', 'd']
     kws = _stack(stackers, 'start', 'end', foo=[10, 20, 30, 40], bar="baz")
     assert len(kws) == len(stackers)
     for i, kw in enumerate(kws):
-        assert set(['start', 'end', 'foo', 'bar']) == set(kw.keys())
+        assert set(['start', 'end', 'foo', 'bar', 'name']) == set(kw.keys())
         assert list(kw['start']['expr'].fields) == stackers[:i]
         assert list(kw['end']['expr'].fields) == stackers[:(i+1)]
         assert kw['foo'] == [10, 20, 30, 40][i]
         assert kw['bar'] == "baz"
+        assert kw['name'] == stackers[i]
 
+def test__stack_broadcast_name_scalar_overrides():
+    stackers = ['a', 'b', 'c', 'd']
+    kws = _stack(stackers, 'start', 'end', foo=[10, 20, 30, 40], bar="baz", name="name")
+    assert len(kws) == len(stackers)
+    for i, kw in enumerate(kws):
+        assert set(['start', 'end', 'foo', 'bar', 'name']) == set(kw.keys())
+        assert list(kw['start']['expr'].fields) == stackers[:i]
+        assert list(kw['end']['expr'].fields) == stackers[:(i+1)]
+        assert kw['foo'] == [10, 20, 30, 40][i]
+        assert kw['bar'] == "baz"
+        assert kw['name'] == "name"
+
+def test__stack_broadcast_name_list_overrides():
+    names = ["aa", "bb", "cc", "dd"]
+    stackers = ['a', 'b', 'c', 'd']
+    kws = _stack(stackers, 'start', 'end', foo=[10, 20, 30, 40], bar="baz", name=names)
+    assert len(kws) == len(stackers)
+    for i, kw in enumerate(kws):
+        assert set(['start', 'end', 'foo', 'bar', 'name']) == set(kw.keys())
+        assert list(kw['start']['expr'].fields) == stackers[:i]
+        assert list(kw['end']['expr'].fields) == stackers[:(i+1)]
+        assert kw['foo'] == [10, 20, 30, 40][i]
+        assert kw['bar'] == "baz"
+        assert kw['name'] == names[i]
+
+@skipIf(not is_pandas, "pandas not installed")
 def test__graph_will_convert_dataframes_to_sources():
     node_source = pd.DataFrame(data=dict(foo=[]))
     edge_source = pd.DataFrame(data=dict(start=[], end=[], bar=[]))
@@ -248,19 +282,33 @@ def test__get_range_with_Range():
         assert r is rng
 
 def test__get_range_with_ndarray():
-    import numpy as np
     r = _get_range(np.array([10, 20]))
     assert isinstance(r, Range1d)
     assert r.start == 10
     assert r.end == 20
 
+def test__get_range_with_too_long_ndarray():
+    with pytest.raises(ValueError):
+        _get_range(np.array([10, 20, 30]))
+
 def test__get_range_with_ndarray_factors():
-    import numpy as np
     f = np.array(["Crosby", "Stills", "Nash", "Young"])
     r = _get_range(f)
     assert isinstance(r, FactorRange)
     assert r.factors == list(f)
 
+@skipIf(not is_pandas, "pandas not installed")
+def test__get_range_with_series():
+    r = _get_range(pd.Series([20, 30]))
+    assert isinstance(r, Range1d)
+    assert r.start == 20
+    assert r.end == 30
+
+@skipIf(not is_pandas, "pandas not installed")
+def test__get_range_with_too_long_series():
+    with pytest.raises(ValueError):
+        _get_range(pd.Series([20, 30, 40]))
+
 def test__get_range_with_string_seq():
     f = ["foo" ,"end", "baz"]
     for t in [list, tuple]:
